@@ -3,6 +3,7 @@ use strict;
 use warnings;
 
 use Carp qw/confess/;
+use Test::Stream::Util qw/USE_XS/;
 
 use Test::Stream::HashBase(
     accessors => [qw/debug nested/],
@@ -28,13 +29,10 @@ sub init {
     confess("No debug info provided!") unless $_[0]->{+DEBUG};
 }
 
-sub to_tap { }
-
-sub update_state { }
-
-sub terminate { undef }
-
-sub global { 0 }
+*to_tap       = USE_XS('1.302004', 'noop') || sub { };
+*update_state = USE_XS('1.302004', 'noop') || sub { };
+*terminate    = USE_XS('1.302004', 'noop') || sub { };
+*global       = USE_XS('1.302004', 'noop') || sub { };
 
 1;
 
